table.fixedHeader-floating {
  position: fixed !important;
  border-bottom-width: 0 !important;
}

table.fixedHeader-locked {
  position: absolute !important;
}

@media print {
  table.fixedHeader-floating {
    display: none;
  }
}
