div.DTFC_LeftHeadWrapper table,
div.DTFC_LeftBodyWrapper table,
div.DTFC_LeftFootWrapper table {
  border-right-width: 0;
}

div.DTFC_RightHeadWrapper table,
div.DTFC_RightBodyWrapper table,
div.DTFC_RightFootWrapper table {
  border-left-width: 0;
}

div.DTFC_LeftHeadWrapper table,
div.DTFC_RightHeadWrapper table {
  margin-bottom: 0 !important;
}

div.DTFC_LeftBodyWrapper table,
div.DTFC_RightBodyWrapper table {
  border-top: none;
  margin: 0 !important;
}

div.DTFC_LeftFootWrapper table,
div.DTFC_RightFootWrapper table {
  margin-top: 0 !important;
  z-index: 2;
}

div.DTFC_Blocker {
  background-color: white;
}
